/*
 * example_basic.c
 *
 * demonstrates simple operation of the libri library to communicate with
 * a DPD80 photodetector.
*/

// libri includes
#include "ri.h"

// for uint16_t types
#include "stdint.h"

//for printf
#include "stdio.h"

int main(int argc, char *argv[])
{
    // variable to check the return status of libri functions.
    // functions return 0 on success and non zero when an error
    // occurs.
    int err = 0;

    // initialize libri
    ri_init();

	// When multiple devices are connected, a specific device is opened by specifying
	// it's serial number (or a subportion of the serial).
	const char *serial = 0;

	// To query all the connected ri devices connected to the computer,  use the
	// ri_list_devices function.  This allocates an array of ri_device_info_t structures
	// containing information about the connected devices.
	//
	// The number of devices found is set by passing a reference to an integer where the number
	// of devices found is stored.
	//
	// The array returned by ri_list_devices must be unnallocated once it is finish being used
	// with the ri_free_device_list function.
	int numdevices = 0;
	ri_device_info_t *deviceinfos = ri_list_devices(&numdevices);


	if (numdevices < 1) {
		printf("no devices found.\n");
		ri_exit();
		return 0;
	}

	printf("found %d devices.\n", numdevices);
	for (int i = 0; i < numdevices; i++) {
		printf("device %d\n"
		       "  product: %s\n"
			   "  serial: %s\n\n", i+1, deviceinfos[i].product, deviceinfos[i].serial);
	}

	// to open a specific device,  specify the serial of the desired device.  Note the entire
	// serial does not have to be specified, if a substring is given the first device with a serial
	// number containing the substring will be opened.

	ri_device *dev = ri_open_from_serial(deviceinfos[numdevices-1].serial);
	if (!dev)
		printf("error opening device %f", deviceinfos[0].serial);
	else {

		// from an open device, the device info can be queried with ri_get_device_info.
		// since a ri_device_info_t type is returned (and not a pointer to an array of them)
		// there is no need to unnallocate this variable later.
		ri_device_info_t devinfo = ri_get_device_info(dev);
		printf("opened device %s", devinfo.serial);

	}

	// cleanup
	if (dev)
		dev = ri_close_device(dev);

	ri_free_device_list(deviceinfos);
	ri_exit();



#ifdef _MSC_VER
	// if Visual Studio get keyboard input at end of program so it doesn't automatically close
	getchar();
#endif
    return 0;
}
